@@ -4,8 +4,9 @@ import asyncio
 import hashlib
 import json
 import time
+from collections.abc import Callable
 from functools import wraps
-from typing import Any, Callable, Optional
+from typing import Any
 
 
 class CacheEntry:
@@ -41,7 +42,7 @@ class MemoryCache:
         self._default_ttl = default_ttl
         self._lock = asyncio.Lock()
 
-    async def get(self, key: str) -> Optional[Any]:
+    async def get(self, key: str) -> Any | None:
         """Get value from cache.
 
         Args:
@@ -60,7 +61,7 @@ class MemoryCache:
                 del self._cache[key]
             return None
 
-    async def set(self, key: str, value: Any, ttl: Optional[float] = None) -> None:
+    async def set(self, key: str, value: Any, ttl: float | None = None) -> None:
         """Set value in cache.
 
         Args:
@@ -114,7 +115,7 @@ class MemoryCache:
         return len(self._cache)
 
     @staticmethod
-    def generate_key(*args, **kwargs) -> str:
+    def generate_key(*args: Any, **kwargs: Any) -> str:
         """Generate cache key from arguments.
 
         Args:
@@ -134,11 +135,11 @@ class MemoryCache:
 
 
 def cache_decorator(
-    ttl: Optional[float] = None,
+    ttl: float | None = None,
     key_prefix: str = "",
-    cache_instance: Optional[MemoryCache] = None,
+    cache_instance: MemoryCache | None = None,
 ) -> Callable:
-    """Decorator for caching async function results.
+    """Decorate async function to cache its results.
 
     Args:
         ttl: TTL for cached results
@@ -154,7 +155,7 @@ def cache_decorator(
 
     def decorator(func: Callable) -> Callable:
         @wraps(func)
-        async def wrapper(*args, **kwargs):
+        async def wrapper(*args: Any, **kwargs: Any) -> Any:
             # Generate cache key
             base_key = MemoryCache.generate_key(*args, **kwargs)
             cache_key = f"{key_prefix}:{func.__name__}:{base_key}"
