@@ -10,6 +10,12 @@ from .instructions import (
 )
 from .models import Attachment, Comment, Epic, Priority, Task, TicketState, TicketType
 from .registry import AdapterRegistry
+from .state_matcher import (
+                           SemanticStateMatcher,
+                           StateMatchResult,
+                           ValidationResult,
+                           get_state_matcher,
+)
 
 __all__ = [
     "Epic",
@@ -26,4 +32,8 @@ __all__ = [
     "InstructionsNotFoundError",
     "InstructionsValidationError",
     "get_instructions",
+    "SemanticStateMatcher",
+    "StateMatchResult",
+    "ValidationResult",
+    "get_state_matcher",
 ]
