@@ -11,10 +11,12 @@ Tests the setup command which intelligently combines init and install:
 from __future__ import annotations
 
 import json
+import subprocess
 from pathlib import Path
 from unittest.mock import Mock, patch
 
 import pytest
+import typer
 from typer.testing import CliRunner
 
 from mcp_ticketer.cli.main import app
@@ -31,8 +33,12 @@ class TestSetupCommand:
         with (
             patch("mcp_ticketer.cli.main.Path.cwd", return_value=tmp_path),
             patch("mcp_ticketer.core.env_discovery.discover_config") as mock_discover,
-            patch("mcp_ticketer.cli.main._prompt_for_adapter_selection") as mock_prompt,
-            patch("mcp_ticketer.cli.main.init") as mock_init,
+            patch(
+                "mcp_ticketer.cli.setup_command._prompt_for_adapter_selection"
+            ) as mock_prompt,
+            patch(
+                "mcp_ticketer.cli.init_command._init_adapter_internal"
+            ) as mock_init_internal,
             patch(
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
@@ -41,6 +47,7 @@ class TestSetupCommand:
             # Setup mocks
             mock_discover.return_value = None
             mock_prompt.return_value = "aitrackdown"
+            mock_init_internal.return_value = True  # Return success
 
             # Mock platform detector
             mock_detector = Mock()
@@ -50,8 +57,8 @@ class TestSetupCommand:
             # Invoke with mix mode to avoid interactive prompts
             runner.invoke(app, ["setup"], input="")
 
-            # Should call init
-            assert mock_init.called
+            # Should call _init_adapter_internal
+            assert mock_init_internal.called
 
     def test_setup_existing_config_keep_settings(self, tmp_path: Path) -> None:
         """Test setup with existing valid config - user keeps settings."""
@@ -70,14 +77,16 @@ class TestSetupCommand:
 
         with (
             patch("mcp_ticketer.cli.main.Path.cwd", return_value=tmp_path),
-            patch("mcp_ticketer.cli.main.init") as mock_init,
+            patch(
+                "mcp_ticketer.cli.init_command._init_adapter_internal"
+            ) as mock_init_internal,
             patch(
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
             patch("typer.confirm") as mock_confirm,
             patch("typer.prompt"),
             patch(
-                "mcp_ticketer.cli.main._prompt_and_update_default_values"
+                "mcp_ticketer.cli.setup_command._prompt_and_update_default_values"
             ) as mock_prompt_defaults,
         ):
             # User confirms to keep existing settings
@@ -90,8 +99,8 @@ class TestSetupCommand:
 
             result = runner.invoke(app, ["setup"], input="")
 
-            # Should NOT call init (config already exists and user kept it)
-            assert not mock_init.called
+            # Should NOT call _init_adapter_internal (config already exists and user kept it)
+            assert not mock_init_internal.called
             # SHOULD call prompt_and_update_default_values
             assert mock_prompt_defaults.called
             assert result.exit_code == 0
@@ -222,8 +231,12 @@ class TestSetupCommand:
         with (
             patch("mcp_ticketer.cli.main.Path.cwd", return_value=tmp_path),
             patch("mcp_ticketer.core.env_discovery.discover_config") as mock_discover,
-            patch("mcp_ticketer.cli.main._prompt_for_adapter_selection") as mock_prompt,
-            patch("mcp_ticketer.cli.main.init") as mock_init,
+            patch(
+                "mcp_ticketer.cli.setup_command._prompt_for_adapter_selection"
+            ) as mock_prompt,
+            patch(
+                "mcp_ticketer.cli.init_command._init_adapter_internal"
+            ) as mock_init_internal,
             patch(
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
@@ -231,6 +244,7 @@ class TestSetupCommand:
             # Setup mocks
             mock_discover.return_value = None
             mock_prompt.return_value = "aitrackdown"
+            mock_init_internal.return_value = True
 
             # Mock platform detector
             mock_detector = Mock()
@@ -239,16 +253,20 @@ class TestSetupCommand:
 
             runner.invoke(app, ["setup", "--force-reinit"], input="")
 
-            # Should call init even though config exists
-            assert mock_init.called
+            # Should call _init_adapter_internal even though config exists
+            assert mock_init_internal.called
 
     def test_setup_skip_platforms(self, tmp_path: Path) -> None:
         """Test setup with --skip-platforms flag."""
         with (
             patch("mcp_ticketer.cli.main.Path.cwd", return_value=tmp_path),
             patch("mcp_ticketer.core.env_discovery.discover_config") as mock_discover,
-            patch("mcp_ticketer.cli.main._prompt_for_adapter_selection") as mock_prompt,
-            patch("mcp_ticketer.cli.main.init") as mock_init,
+            patch(
+                "mcp_ticketer.cli.setup_command._prompt_for_adapter_selection"
+            ) as mock_prompt,
+            patch(
+                "mcp_ticketer.cli.init_command._init_adapter_internal"
+            ) as mock_init_internal,
             patch(
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
@@ -256,6 +274,7 @@ class TestSetupCommand:
             # Setup mocks
             mock_discover.return_value = None
             mock_prompt.return_value = "aitrackdown"
+            mock_init_internal.return_value = True
 
             # Mock detector should NOT be called when skipping platforms
             mock_detector = Mock()
@@ -263,8 +282,8 @@ class TestSetupCommand:
 
             runner.invoke(app, ["setup", "--skip-platforms"], input="")
 
-            # Should call init but not detect platforms
-            assert mock_init.called
+            # Should call _init_adapter_internal but not detect platforms
+            assert mock_init_internal.called
             assert not mock_detector.detect_all.called
 
     def test_setup_with_platforms_install_all(self, tmp_path: Path) -> None:
@@ -286,7 +305,7 @@ class TestSetupCommand:
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
             patch(
-                "mcp_ticketer.cli.main._check_existing_platform_configs"
+                "mcp_ticketer.cli.setup_command._check_existing_platform_configs"
             ) as mock_check,
             patch(
                 "mcp_ticketer.cli.mcp_configure.configure_claude_mcp"
@@ -336,7 +355,7 @@ class TestSetupCommand:
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
             patch(
-                "mcp_ticketer.cli.main._check_existing_platform_configs"
+                "mcp_ticketer.cli.setup_command._check_existing_platform_configs"
             ) as mock_check,
             patch(
                 "mcp_ticketer.cli.mcp_configure.configure_claude_mcp"
@@ -390,7 +409,7 @@ class TestSetupCommand:
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
             patch(
-                "mcp_ticketer.cli.main._check_existing_platform_configs"
+                "mcp_ticketer.cli.setup_command._check_existing_platform_configs"
             ) as mock_check,
             patch(
                 "mcp_ticketer.cli.mcp_configure.configure_claude_mcp"
@@ -440,7 +459,7 @@ class TestSetupCommand:
                 "mcp_ticketer.cli.platform_detection.PlatformDetector"
             ) as mock_detector_class,
             patch(
-                "mcp_ticketer.cli.main._check_existing_platform_configs"
+                "mcp_ticketer.cli.setup_command._check_existing_platform_configs"
             ) as mock_check,
             patch(
                 "mcp_ticketer.cli.mcp_configure.configure_claude_mcp"
@@ -510,7 +529,7 @@ class TestPromptAndUpdateDefaultValues:
 
     def test_prompt_and_update_with_new_values(self, tmp_path: Path) -> None:
         """Test prompting and updating default values."""
-        from mcp_ticketer.cli.main import _prompt_and_update_default_values
+        from mcp_ticketer.cli.setup_command import _prompt_and_update_default_values
 
         config_dir = tmp_path / ".mcp-ticketer"
         config_dir.mkdir(parents=True, exist_ok=True)
@@ -550,7 +569,7 @@ class TestPromptAndUpdateDefaultValues:
 
     def test_prompt_and_update_preserves_existing_values(self, tmp_path: Path) -> None:
         """Test that existing values are passed to prompt function."""
-        from mcp_ticketer.cli.main import _prompt_and_update_default_values
+        from mcp_ticketer.cli.setup_command import _prompt_and_update_default_values
 
         config_dir = tmp_path / ".mcp-ticketer"
         config_dir.mkdir(parents=True, exist_ok=True)
@@ -586,7 +605,7 @@ class TestPromptAndUpdateDefaultValues:
 
     def test_prompt_and_update_handles_invalid_json(self, tmp_path: Path) -> None:
         """Test error handling for invalid JSON config."""
-        from mcp_ticketer.cli.main import _prompt_and_update_default_values
+        from mcp_ticketer.cli.setup_command import _prompt_and_update_default_values
 
         config_dir = tmp_path / ".mcp-ticketer"
         config_dir.mkdir(parents=True, exist_ok=True)
@@ -610,7 +629,7 @@ class TestPromptAndUpdateDefaultValues:
 
     def test_prompt_and_update_handles_missing_file(self, tmp_path: Path) -> None:
         """Test error handling for missing config file."""
-        from mcp_ticketer.cli.main import _prompt_and_update_default_values
+        from mcp_ticketer.cli.setup_command import _prompt_and_update_default_values
 
         config_file = tmp_path / ".mcp-ticketer" / "config.json"
         # Don't create the file
@@ -629,13 +648,279 @@ class TestPromptAndUpdateDefaultValues:
             )
 
 
+@pytest.mark.unit
+class TestCheckAndInstallAdapterDependencies:
+    """Test suite for _check_and_install_adapter_dependencies helper function."""
+
+    def test_aitrackdown_no_dependencies_needed(self) -> None:
+        """Test that aitrackdown adapter reports no extra dependencies needed."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with patch("mcp_ticketer.cli.main.Console") as mock_console_class:
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            result = _check_and_install_adapter_dependencies(
+                "aitrackdown", mock_console
+            )
+
+            # Should return True (no dependencies needed)
+            assert result is True
+
+            # Verify message was printed
+            assert any(
+                "No extra dependencies required" in str(call)
+                for call in mock_console.print.call_args_list
+            )
+
+    def test_dependencies_already_installed(self) -> None:
+        """Test when adapter dependencies are already installed."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is already installed
+            mock_check.return_value = True
+
+            result = _check_and_install_adapter_dependencies("linear", mock_console)
+
+            # Should return True (already installed)
+            assert result is True
+
+            # Verify success message was printed
+            assert any(
+                "already installed" in str(call)
+                for call in mock_console.print.call_args_list
+            )
+
+    def test_dependencies_missing_user_accepts_installation(self) -> None:
+        """Test installing dependencies when user accepts."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+            patch("typer.confirm") as mock_confirm,
+            patch("subprocess.check_call") as mock_subprocess,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is NOT installed
+            mock_check.return_value = False
+
+            # User accepts installation
+            mock_confirm.return_value = True
+
+            # Mock successful installation
+            mock_subprocess.return_value = 0
+
+            result = _check_and_install_adapter_dependencies("github", mock_console)
+
+            # Should return True (installation succeeded)
+            assert result is True
+
+            # Verify subprocess was called with correct command
+            assert mock_subprocess.called
+            call_args = mock_subprocess.call_args[0][0]
+            assert "pip" in call_args
+            assert "install" in call_args
+            assert "mcp-ticketer[github]" in call_args
+
+            # Verify success message was printed
+            assert any(
+                "Successfully installed" in str(call)
+                for call in mock_console.print.call_args_list
+            )
+
+    def test_dependencies_missing_user_declines_installation(self) -> None:
+        """Test when user declines to install dependencies."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+            patch("typer.confirm") as mock_confirm,
+            patch("subprocess.check_call") as mock_subprocess,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is NOT installed
+            mock_check.return_value = False
+
+            # User declines installation
+            mock_confirm.return_value = False
+
+            result = _check_and_install_adapter_dependencies("jira", mock_console)
+
+            # Should return True (user declined, but we continue)
+            assert result is True
+
+            # Verify subprocess was NOT called
+            assert not mock_subprocess.called
+
+            # Verify manual installation instructions were shown
+            assert any(
+                "Install manually" in str(call)
+                for call in mock_console.print.call_args_list
+            )
+            assert any(
+                "pip install mcp-ticketer[jira]" in str(call)
+                for call in mock_console.print.call_args_list
+            )
+
+    def test_installation_fails_gracefully(self) -> None:
+        """Test graceful handling of installation failure."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+            patch("typer.confirm") as mock_confirm,
+            patch("subprocess.check_call") as mock_subprocess,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is NOT installed
+            mock_check.return_value = False
+
+            # User accepts installation
+            mock_confirm.return_value = True
+
+            # Mock installation failure
+            mock_subprocess.side_effect = subprocess.CalledProcessError(
+                1, "pip", stderr=b"Installation error"
+            )
+
+            result = _check_and_install_adapter_dependencies("linear", mock_console)
+
+            # Should return True (continue despite failure)
+            assert result is True
+
+            # Debug: print all calls
+            all_calls = [str(call) for call in mock_console.print.call_args_list]
+
+            # Verify error message and manual instructions were shown
+            # Check with more flexible pattern matching
+            has_failed = any("fail" in str(call).lower() for call in all_calls)
+            has_manual = any("manual" in str(call).lower() for call in all_calls)
+
+            assert has_failed, f"Expected 'failed' message in: {all_calls}"
+            assert has_manual, f"Expected 'manual' message in: {all_calls}"
+
+    def test_user_cancels_installation_prompt(self) -> None:
+        """Test when user cancels the installation prompt."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+            patch("typer.confirm") as mock_confirm,
+            patch("subprocess.check_call") as mock_subprocess,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is NOT installed
+            mock_check.return_value = False
+
+            # User cancels prompt (Ctrl+C)
+            mock_confirm.side_effect = typer.Abort()
+
+            result = _check_and_install_adapter_dependencies("github", mock_console)
+
+            # Should return True (cancelled, but we continue)
+            assert result is True
+
+            # Verify subprocess was NOT called
+            assert not mock_subprocess.called
+
+            # Verify cancellation message was shown
+            assert any(
+                "cancelled" in str(call).lower()
+                for call in mock_console.print.call_args_list
+            )
+
+    def test_all_adapter_types_have_dependencies_defined(self) -> None:
+        """Test that all adapter types have dependency mappings."""
+        from mcp_ticketer.cli.setup_command import ADAPTER_DEPENDENCIES
+
+        # All known adapter types should be in the mapping
+        expected_adapters = ["linear", "jira", "github", "aitrackdown"]
+
+        for adapter in expected_adapters:
+            assert adapter in ADAPTER_DEPENDENCIES, f"{adapter} not in mapping"
+
+    def test_linear_adapter_import_check(self) -> None:
+        """Test that linear adapter correctly checks for gql package."""
+        from mcp_ticketer.cli.setup_command import (
+            _check_and_install_adapter_dependencies,
+        )
+
+        with (
+            patch("mcp_ticketer.cli.main.Console") as mock_console_class,
+            patch(
+                "mcp_ticketer.cli.setup_command._check_package_installed"
+            ) as mock_check,
+            patch("typer.confirm") as mock_confirm,
+            patch("subprocess.check_call") as mock_subprocess,
+        ):
+            mock_console = Mock()
+            mock_console_class.return_value = mock_console
+
+            # Mock that package is NOT installed
+            mock_check.return_value = False
+
+            # User accepts installation
+            mock_confirm.return_value = True
+            mock_subprocess.return_value = 0
+
+            result = _check_and_install_adapter_dependencies("linear", mock_console)
+
+            # Should attempt installation
+            assert result is True
+            # Verify correct extras are used
+            if mock_subprocess.called:
+                call_args = mock_subprocess.call_args[0][0]
+                assert "mcp-ticketer[linear]" in call_args
+
+
 @pytest.mark.unit
 class TestCheckExistingPlatformConfigs:
     """Test suite for _check_existing_platform_configs helper."""
 
     def test_check_claude_code_configured(self, tmp_path: Path) -> None:
         """Test detection of Claude Code configuration."""
-        from mcp_ticketer.cli.main import _check_existing_platform_configs
+        from mcp_ticketer.cli.setup_command import _check_existing_platform_configs
 
         # Create mock Claude Code config
         claude_config_path = Path.home() / ".claude.json"
@@ -663,7 +948,7 @@ class TestCheckExistingPlatformConfigs:
 
     def test_check_no_configs(self, tmp_path: Path) -> None:
         """Test when no platforms are configured."""
-        from mcp_ticketer.cli.main import _check_existing_platform_configs
+        from mcp_ticketer.cli.setup_command import _check_existing_platform_configs
 
         mock_platform = Mock()
         mock_platform.name = "claude-code"
